@@ -19,8 +19,7 @@
 */
 
 #include "editorproxymodel.h"
-#include "networkmodelitem.h"
-#include "networkmodel.h"
+#include "uiutils.h"
 
 EditorProxyModel::EditorProxyModel(QObject* parent)
     : QSortFilterProxyModel(parent)
@@ -47,17 +46,10 @@ bool EditorProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
         return false;
     }
 
-#if NM_CHECK_VERSION(0, 9, 10)
     const NetworkManager::ConnectionSettings::ConnectionType type = (NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(index, NetworkModel::TypeRole).toUInt();
-    if (type == NetworkManager::ConnectionSettings::Generic) {
+    if (!UiUtils::isConnectionTypeSupported(type)) {
         return false;
     }
-#if NM_CHECK_VERSION(1, 1, 92)
-    if (type == NetworkManager::ConnectionSettings::Tun) {
-        return false;
-    }
-#endif
-#endif
 
     NetworkModelItem::ItemType itemType = (NetworkModelItem::ItemType)sourceModel()->data(index, NetworkModel::ItemTypeRole).toUInt();
     if (itemType == NetworkModelItem::AvailableAccessPoint || itemType == NetworkModelItem::AvailableNsp) {
@@ -66,8 +58,10 @@ bool EditorProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
 
     const QString pattern = filterRegExp().pattern();
     if (!pattern.isEmpty()) {  // filtering on data (connection name), wildcard-only
-        const QString data = sourceModel()->data(index, Qt::DisplayRole).toString();
-        // qCDebug(PLASMA_NM) << "Filtering " << data << "with pattern" << pattern;
+        QString data = sourceModel()->data(index, Qt::DisplayRole).toString();
+        if (data.isEmpty()) {
+            data = sourceModel()->data(index, NetworkModel::NameRole).toString();
+        }
         return data.contains(pattern, Qt::CaseInsensitive);
     }
 
@@ -76,13 +70,47 @@ bool EditorProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
 
 bool EditorProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
-    if (sourceModel()) { // special sorting case, only for editor
-        if (sortColumn() == 2) {
-            const QDateTime leftDate = sourceModel()->data(left, NetworkModel::TimeStampRole).toDateTime();
-            const QDateTime rightDate = sourceModel()->data(right, NetworkModel::TimeStampRole).toDateTime();
-            return leftDate < rightDate;
+    const bool leftConnected = sourceModel()->data(left, NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+    const QString leftName = sourceModel()->data(left, NetworkModel::NameRole).toString();
+    const UiUtils::SortedConnectionType leftType = UiUtils::connectionTypeToSortedType((NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(left, NetworkModel::TypeRole).toUInt());
+    const QString leftVpnType = sourceModel()->data(left, NetworkModel::VpnType).toString();
+    const QDateTime leftDate = sourceModel()->data(left, NetworkModel::TimeStampRole).toDateTime();
+
+    const bool rightConnected = sourceModel()->data(right, NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+    const QString rightName = sourceModel()->data(right, NetworkModel::NameRole).toString();
+    const UiUtils::SortedConnectionType rightType = UiUtils::connectionTypeToSortedType((NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(right, NetworkModel::TypeRole).toUInt());
+    const QString rightVpnType = sourceModel()->data(right, NetworkModel::VpnType).toString();
+    const QDateTime rightDate = sourceModel()->data(right, NetworkModel::TimeStampRole).toDateTime();
+
+    if (leftType < rightType) {
+        return false;
+    } else if (leftType > rightType) {
+        return true;
+    }
+
+    if (leftType == rightType && leftType == UiUtils::Vpn) {
+        if (QString::localeAwareCompare(leftVpnType, rightVpnType) < 0) {
+            return false;
+        } else if (QString::localeAwareCompare(leftVpnType, rightVpnType) > 0) {
+            return true;
         }
     }
 
-    return QSortFilterProxyModel::lessThan(left, right);
+    if (leftConnected < rightConnected) {
+        return true;
+    } else if (leftConnected > rightConnected) {
+        return false;
+    }
+
+    if (leftDate > rightDate) {
+        return false;
+    } else if (leftDate < rightDate) {
+        return true;
+    }
+
+    if (QString::localeAwareCompare(leftName, rightName) > 0) {
+        return true;
+    } else {
+        return false;
+    }
 }
